Learn R Programming

scico (version 1.1.0)

scico_palette_show: Show the different scico palettes

Description

This is a simple function to show a gradient of the different palettes available in the scico package

Usage

scico_palette_show(palettes = scico_palette_names())

Arguments

palettes

One or more palette names to show

Examples

Run this code
# NOT RUN {
scico_palette_show()

# }

Run the code above in your browser using DataLab