powered by
This is a simple function to show a gradient of the different palettes available in the scico package
scico
scico_palette_show(palettes = scico_palette_names())
One or more palette names to show
# NOT RUN { scico_palette_show() # }
Run the code above in your browser using DataLab